@@ -95,8 +95,9 @@ the generated documentation however you want! pdoc's job is to "just" produce se
 A very simple way to host your API documentation is to set up a continuous integration job which
 pushes your documentation to GitHub Pages. This keeps your docs updated automatically.
 
- 1. Enable GitHub Actions and GitHub Pages in your project's settings.
- 2. Copy pdoc's GitHub Actions workflow into your own repository and adjust it to how you build your docs:
+ 1. Enable GitHub Actions and GitHub Pages for your project.
+ 2. In the GitHub Pages settings, select GitHub Actions as your build and deployment source.
+ 3. Copy pdoc's GitHub Actions workflow into your own repository and adjust it to how you build your docs:
     [`.github/workflows/docs.yml`](https://github.com/mitmproxy/pdoc/blob/main/.github/workflows/docs.yml)
 
 That's it – no need to fiddle with any secrets or set up any `gh-pages` branches. 🥳
@@ -127,6 +128,7 @@ the docstring should come on the line immediately following `class
 the file. These docstrings are what you see for each module, class,
 function and method listed in the documentation produced by pdoc.
 
+
 ## ...document variables?
 
 Python itself [does not attach docstrings to
@@ -169,6 +171,7 @@ class GoldenRetriever(Dog):
     """Full Name (different for each instance)"""
 ```
 
+
 ## ...control what is documented?
 
 The public interface of a module is determined through one of two
@@ -206,6 +209,7 @@ pdoc foo !foo.bar
 Likewise, `pdoc pdoc !pdoc.` would document the pdoc module itself, but none of its submodules. Patterns are always
 matched on the final module name, even if modules are passed as file paths.
 
+
 ## ...link to other identifiers?
 
 In your documentation, you can link to other identifiers by enclosing them in backticks:
@@ -218,6 +222,7 @@ pdoc will link all identifiers that are rendered in the current run.
 This means that you need to run `pdoc module_a module_b` to have interlinking between module_a and module_b.
 If you run `pdoc module_a` followed by `pdoc module_b`, there will be no cross-linking between the two modules.
 
+
 ## ...change the item order?
 
 By default, documentation items are sorted in order of (first) appearance in the source code.
@@ -225,6 +230,7 @@ This means that if you want to move a particular function to the beginning of yo
 you need to move it there in your source code. This is not only useful to the readers of your documentation,
 but also useful to the consumers of your source code.
 
+
 ## ...use numpydoc or Google docstrings?
 
 While pdoc prefers docstrings that are plain Markdown, it also understands numpydoc and Google-style docstrings.
@@ -270,6 +276,17 @@ You can include external Markdown files in your documentation by using reStructu
 Since version 11, pdoc processes such reStructuredText elements by default.
 
 
+## ...add a title page?
+
+The landing page for your documentation is your project's top-level `<modulename>/__init__.py` file.
+Adding a module-level docstring here is a great way to introduce users to your project.
+For example, the documentation you are reading right now is sourced from
+[`pdoc/__init__.py`](https://github.com/mitmproxy/pdoc/blob/main/pdoc/__init__.py).
+You can also include your title page from a [Markdown file](#include-markdown-files).
+
+If you have multiple top-level modules, a custom title page requires modifying the `index.html.jinja2` template.
+You can find an example in [#410](https://github.com/mitmproxy/pdoc/issues/410).
+
 ## ...edit pdoc's HTML template?
 
 For more advanced customization, we can edit pdoc's
@@ -300,6 +317,7 @@ pdoc -t . ./demo.py
 See [`examples/`](https://github.com/mitmproxy/pdoc/tree/main/examples/)
 for more examples.
 
+
 ## ...pass arguments to the Jinja2 template?
 
 If you need to pass additional data to pdoc's Jinja2 templates,
@@ -432,22 +450,18 @@ You can find an example in [`examples/library-usage`](https://github.com/mitmpro
 from __future__ import annotations
 
 __docformat__ = "markdown"  # explicitly disable rST processing in the examples above.
-__version__ = "12.0.2"  # this is read from setup.py
+__version__ = "12.2.0"  # this is read from setup.py
 
-import traceback
-import warnings
 from pathlib import Path
 from typing import overload
 
 from pdoc import doc, extract, render
-from pdoc._compat import Literal
 
 
 @overload
 def pdoc(
     *modules: Path | str,
     output_directory: None = None,
-    format: Literal["html"] = "html",
 ) -> str:
     pass
 
@@ -456,7 +470,6 @@ def pdoc(
 def pdoc(
     *modules: Path | str,
     output_directory: Path,
-    format: Literal["html"] = "html",
 ) -> None:
     pass
 
@@ -464,7 +477,6 @@ def pdoc(
 def pdoc(
     *modules: Path | str,
     output_directory: Path | None = None,
-    format: Literal["html"] = "html",
 ) -> str | None:
     """
     Render the documentation for a list of modules.
@@ -476,29 +488,12 @@ def pdoc(
 
     Rendering options can be configured by calling `pdoc.render.configure` in advance.
     """
-    if format not in ("html", "markdown", "repr"):
-        raise ValueError(f"Invalid rendering format {format!r}.")
-    if format == "markdown":  # pragma: no cover
-        raise NotImplementedError(
-            "Markdown support is currently unimplemented, but PRs are welcome!"
-        )
-
     all_modules: dict[str, doc.Module] = {}
     for module_name in extract.walk_specs(modules):
-        try:
-            all_modules[module_name] = doc.Module.from_name(module_name)
-        except RuntimeError:
-            warnings.warn(f"Error importing {module_name}:\n{traceback.format_exc()}")
-
-    if not all_modules:
-        raise RuntimeError("Unable to import any modules.")
+        all_modules[module_name] = doc.Module.from_name(module_name)
 
     for module in all_modules.values():
-        if format == "html":
-            out = render.html_module(module, all_modules)
-        else:
-            out = render.repr_module(module)
-
+        out = render.html_module(module, all_modules)
         if not output_directory:
             return out
         else:
@@ -507,13 +502,13 @@ def pdoc(
             outfile.write_bytes(out.encode())
 
     assert output_directory
-    if format == "html":
-        index = render.html_index(all_modules)
-        if index:
-            (output_directory / "index.html").write_bytes(index.encode())
 
-        search = render.search_index(all_modules)
-        if search:
-            (output_directory / "search.js").write_bytes(search.encode())
+    index = render.html_index(all_modules)
+    if index:
+        (output_directory / "index.html").write_bytes(index.encode())
+
+    search = render.search_index(all_modules)
+    if search:
+        (output_directory / "search.js").write_bytes(search.encode())
 
     return None
