@@ -45,12 +45,6 @@ mainargs.add_argument(
     type=Path,
     help="Write rendered documentation to the specified directory, don't start a webserver.",
 )
-# may be added again in the future:
-# formats = parser.add_mutually_exclusive_group()
-# formats.add_argument("--html", dest="format", action="store_const", const="html")
-# formats.add_argument(
-#     "--markdown", dest="format", action="store_const", const="markdown"
-# )
 
 renderopts = parser.add_argument_group(f"{white}Customize Rendering{default}")
 renderopts.add_argument(
@@ -192,7 +186,6 @@ def cli(args: list[str] = None) -> None:
         pdoc.pdoc(
             *opts.modules,
             output_directory=opts.output_directory,
-            format="html",  # opts.format or
         )
         return
     else:
