@@ -17,6 +17,7 @@ By convention, all attributes are read-only, although this is not enforced at ru
 """
 from __future__ import annotations
 
+import dataclasses
 import enum
 import inspect
 import os
@@ -42,7 +43,13 @@ from pdoc.doc_types import (
     safe_eval_type,
 )
 
-from ._compat import cache, cached_property, formatannotation, get_origin
+from ._compat import (
+    cache,
+    cached_property,
+    formatannotation,
+    get_origin,
+    singledispatchmethod,
+)
 
 
 def _include_fullname_in_traceback(f):
@@ -227,14 +234,14 @@ class Namespace(Doc[T], metaclass=ABCMeta):
     @cached_property
     @abstractmethod
     def own_members(self) -> list[Doc]:
-        """A list of all own (i.e. non-inherited) members"""
+        """A list of all own (i.e. non-inherited) `members`."""
 
     @cached_property
     def members(self) -> dict[str, Doc]:
         """A mapping from all members to their documentation objects.
 
         This mapping includes private members; they are only filtered out as part of the template logic.
-
+        Constructors for enums, dicts, and abstract base classes are not picked up unless they have a custom docstring.
         """
         members: dict[str, Doc] = {}
         for name, obj in self._member_objects.items():
@@ -246,7 +253,7 @@ class Namespace(Doc[T], metaclass=ABCMeta):
             is_property = (
                 isinstance(obj, (property, cached_property))
                 or
-                # Python 3.9: @classmethod @property is now allowed.
+                # Python 3.9 - 3.10: @classmethod @property is allowed.
                 is_classmethod
                 and isinstance(obj.__func__, (property, cached_property))
             )
@@ -559,8 +566,16 @@ class Class(Namespace[type]):
         if doc == dict.__doc__:
             # Don't display default docstring for dict subclasses (primarily TypedDict).
             return ""
-        else:
-            return doc
+        is_dataclass_with_default_docstring = (
+            dataclasses.is_dataclass(self.obj)
+            # from https://github.com/python/cpython/blob/3.10/Lib/dataclasses.py
+            and doc
+            == self.obj.__name__
+            + str(inspect.signature(self.obj)).replace(" -> None", "")
+        )
+        if is_dataclass_with_default_docstring:
+            return ""
+        return doc
 
     @cached_property
     def _var_docstrings(self) -> dict[str, str]:
@@ -644,6 +659,8 @@ class Class(Namespace[type]):
                 unsorted.setdefault(name, obj)
         for name in self._var_docstrings:
             unsorted.setdefault(name, empty)
+        for name in self._var_annotations:
+            unsorted.setdefault(name, empty)
 
         init_has_no_doc = unsorted.get("__init__", object.__init__).__doc__ in (
             None,
@@ -811,6 +828,8 @@ class Function(Doc[types.FunctionType]):
         unwrapped: types.FunctionType
         if isinstance(func, (classmethod, staticmethod)):
             unwrapped = func.__func__  # type: ignore
+        elif isinstance(func, singledispatchmethod):
+            unwrapped = func.func  # type: ignore
         else:
             unwrapped = func
         super().__init__(modulename, qualname, unwrapped, taken_from)
@@ -839,7 +858,15 @@ class Function(Doc[types.FunctionType]):
             cls = sys.modules.get(_safe_getattr(self.obj, "__module__", None), None)
             for name in _safe_getattr(self.obj, "__qualname__", "").split(".")[:-1]:
                 cls = _safe_getattr(cls, name, None)
-            doc = _safe_getdoc(_safe_getattr(cls, self.name, None))
+
+            unbound = _safe_getattr(cls, "__dict__", {}).get(self.name)
+            is_classmethod_property = isinstance(unbound, classmethod) and isinstance(
+                unbound.__func__, (property, cached_property)
+            )
+            if not is_classmethod_property:
+                # We choke on @classmethod @property, but that's okay because it's been deprecated with Python 3.11.
+                # Directly accessing them would give us the return value, which has the wrong docstring.
+                doc = _safe_getdoc(_safe_getattr(cls, self.name, None))
 
         if doc == object.__init__.__doc__:
             # inspect.getdoc(Foo.__init__) returns the docstring, for object.__init__ if left undefined...
