@@ -15,15 +15,11 @@ import types
 import typing
 import warnings
 from types import BuiltinFunctionType, ModuleType
-from typing import (
-    Any,
-    Optional,
-    TYPE_CHECKING,
-)
+from typing import Any, TYPE_CHECKING
 from typing import _GenericAlias  # type: ignore
 
 from . import extract
-from ._compat import GenericAlias, Literal, UnionType, get_args, get_origin
+from ._compat import GenericAlias, Literal, UnionType, get_origin
 from .doc_ast import type_checking_sections
 
 if TYPE_CHECKING:
@@ -57,20 +53,9 @@ NonUserDefinedCallables = (
 # ✂ end ✂
 
 
-def formatannotation(annotation: Any) -> str:
-    """
-    Like `inspect.formatannotation()`, but with a small bugfix for Python 3.9's GenericAlias annotations.
-    """
-    # a small inconsistency in Python 3.9,
-    # formatannotation(list[str]) returns "list".
-    if isinstance(annotation, type) and get_args(annotation):
-        return repr(annotation)
-    return inspect.formatannotation(annotation)
-
-
 def resolve_annotations(
     annotations: dict[str, Any],
-    module: Optional[ModuleType],
+    module: ModuleType | None,
     fullname: str,
 ) -> dict[str, Any]:
     """
@@ -83,7 +68,7 @@ def resolve_annotations(
 
     resolved = {}
     for name, value in annotations.items():
-        resolved[name] = safe_eval_type(value, ns, module, fullname)
+        resolved[name] = safe_eval_type(value, ns, module, f"{fullname}.{name}")
 
     return resolved
 
@@ -91,7 +76,7 @@ def resolve_annotations(
 def safe_eval_type(
     t: Any,
     globalns,
-    module: Optional[types.ModuleType],
+    module: types.ModuleType | None,
     fullname: str,
 ) -> Any:
     """
@@ -113,7 +98,19 @@ def safe_eval_type(
         err = str(e)
         _, mod, _ = err.split("'")
     except Exception as e:
-        warnings.warn(f"Error parsing type annotation {t} for {fullname}: {e}")
+        if "unsupported operand type(s) for |" in str(e) and sys.version_info < (3, 10):
+            py_ver = ".".join(str(x) for x in sys.version_info[:3])
+            warnings.warn(
+                f"Error parsing type annotation {t} for {fullname}: {e}. "
+                f"You are likely attempting to use Python 3.10 syntax (PEP 604 union types) with an older Python "
+                f"release. `X | Y`-style type annotations are invalid syntax on Python {py_ver}, which is what your "
+                f"pdoc instance is using. `from future import __annotations__` (PEP 563) postpones evaluation of "
+                f"annotations, which is why your program won't crash right away. However, pdoc needs to evaluate your "
+                f"type annotations and is unable to do so on Python {py_ver}. To fix this issue, either invoke pdoc "
+                f"from Python 3.10+, or switch to `typing.Union[]` syntax."
+            )
+        else:
+            warnings.warn(f"Error parsing type annotation {t} for {fullname}: {e}")
         return t
 
     # Simple _eval_type has failed. We now execute all TYPE_CHECKING sections in the module and try again.
@@ -127,8 +124,13 @@ def safe_eval_type(
             )
         try:
             return _eval_type(t, globalns, None)
-        except Exception:
-            pass
+        except (AttributeError, NameError):
+            pass  # still not found
+        except Exception as e:
+            warnings.warn(
+                f"Error parsing type annotation {t} for {fullname} after evaluating TYPE_CHECKING blocks: {e}"
+            )
+            return t
 
     try:
         val = extract.load_module(mod)
